import os
import subprocess
import sys
import time
from sys import stderr
from dotenv import load_dotenv
from sys import platform
import io

PYTHON = "python"

if platform == "darwin":
    # OS X
    PYTHON = "python3"

# current path will return the workspace
currentpath = os.getcwd()
currentdir = os.path.dirname(currentpath)

class ProcessResults:
    returncode = -1
    stdout = ""
    stderr = ""

def run(script):
    REPO_ROOT = os.environ['GITPOD_REPO_ROOT']
    COVERAGE_DIR = os.path.join(REPO_ROOT,".snowqm","coverage_data")
    # make sure dir exists
    os.makedirs(COVERAGE_DIR, exist_ok=True)
    os.environ['COVERAGE_PROCESS_START'] = os.path.join(REPO_ROOT,".coveragerc")
    load_dotenv()
    capture = False
    script_env = os.environ.copy()
    # we create a coverage file for each run
    script_env['COVERAGE_FILE'] = os.path.join(COVERAGE_DIR, ".coverage." + script.replace(os.sep,"_")) 
    basepath = os.path.dirname(script)
    script_only = os.path.basename(script).replace(".py","")
    process = subprocess.run([PYTHON,"-m",script_only], env=script_env,cwd=basepath, capture_output=capture)
    return process


import io
from setuptools import setup

def read_files(files):
    data = []
    for file in files:
        with io.open(file, encoding='utf-8') as f:
            data.append(f.read())
    return "\n".join(data)

long_description = read_files(['README.md'])

setup(name='snowconvert-test-utils',
      version='0.2',
      url='https://github.com/orellabac/snowconvert-test-utils',
      description="Adds some helper functions to make testing python modules easier",
      long_description=long_description,
      long_description_content_type='text/markdown',
      author='Mauricio Rojas',
      author_email='mauricio.rojas@mobilize.net',
      license='MIT',
      install_requires=[
        'snowflake-connector-python',
        'pytest',
        'python-dotenv'],
      packages=['testutils'],
      zip_safe=False)
